Response

Struct Response 

pub struct Response {
    pub messages: Vec<Message>,
    pub usage: Option<Usage>,
    pub model: String,
    pub provider: ProviderKind,
    pub finish_reason: Option<String>,
}
The response from an AI generation request.

Examples

use rai_sdk::{ClientBuilder, Model};

let client = ClientBuilder::new()
    .from_env()
    .model(Model::gpt4o_mini())
    .build()?;

let response = client.request().prompt("Say hi.").generate().await?;

println!("{}", response.text());
println!("served by {} using {}", response.provider, response.model);
if let Some(usage) = &response.usage {
    println!("{:?} total tokens", usage.total_tokens);
}

Fields

messages: Vec<Message>

The generated message(s).

usage: Option<Usage>

Token usage information.

model: String

The model that was used.

provider: ProviderKind

The provider that was used.

finish_reason: Option<String>

Finish reason (e.g., “stop”, “length”, “tool_use”).

Implementations

Source

impl Response

pub fn text(&self) -> String

Helper to extract the text content from the first message in the response.

Returns an empty string if the response contains no messages.